@@ -71,7 +71,7 @@ class CrsTransform(object):
                 startVal /= self.cell_dims[i] / self.axis_sampling[i]                
                 vCRS.put_by_idx(i, startVal)        
         else: #they are not orthogonal        
-            vFraction = self.deOrthoMat.multiply(XYZ, True)
+            vFraction = self.deOrthoMat.multiply(XYZ, False)
             for i in range(3):            
                 val = vFraction.get_by_idx(i) * self.axis_sampling[i] - self.crs_starts[self.map2xyz[i]];
                 vCRS.put_by_idx(i, val);                    
